==> dyte_client-0.1.1.tar.gz: ios/Classes/DyteMeetingPlugin.m <==
//
//  DyteMeetingPlugin.m
//  dyte_client
//
//  Created by Rohit Bhatia on 7/12/21.
//

#import "DyteMeetingPlugin.h"
#import <Flutter/Flutter.h>
#import <UIKit/UIKit.h>
#import "FLNativeViewFactory.h"
@import DyteSdk;


static NSString *const CHANNEL_NAME = @"dyte_client";

@interface DyteMeetingPlugin ()
@property(nonatomic, retain) FlutterMethodChannel *channel;
@end

@implementation DyteMeetingPlugin

+ (void)registerWithRegistrar:(nonnull NSObject<FlutterPluginRegistrar> *)registrar {
    FlutterMethodChannel *channel =
         [FlutterMethodChannel methodChannelWithName:CHANNEL_NAME
                                     binaryMessenger:[registrar messenger]];
    FLNativeViewFactory* factory =
        [[FLNativeViewFactory alloc] initWithMessenger:registrar.messenger];
    DyteMeetingPlugin *instance = [[DyteMeetingPlugin alloc] init];
     [registrar addMethodCallDelegate:instance channel:channel];
     [registrar addApplicationDelegate:instance];
    [registrar registerViewFactory:factory withId:@"dyte-meeting-view"];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    DyteSelfParticipant *selfPartcipant = [DyteSelfParticipant sharedInstance];
    DyteParticipants *participantsInstance = [DyteParticipants sharedInstance];
    if ([@"getPlatformVersion"  isEqualToString:call.method]) {
        UIDevice* device = UIDevice.currentDevice;
        result(device.systemVersion);
    } else if ([@"getSelf" isEqualToString:call.method]) {
        result(selfPartcipant);
    } else if ([@"getMeetingParticipants" isEqualToString:call.method]) {
        result(participantsInstance.participants);
    } else if ([@"selfEnableAudio"isEqualToString:call.method] && !(selfPartcipant.audioEnabled)) {
        // In SDK, we currently have toggle audio so we only fire this event if audio is not enabled
        [selfPartcipant toggleAudio];
    } else if ([@"selfDisableAudio" isEqualToString:call.method] && selfPartcipant.audioEnabled) {
        [selfPartcipant toggleAudio];
    } else if ([@"selfDisableVideo" isEqualToString:call.method] && selfPartcipant.videoEnabled) {
        [selfPartcipant toggleVideo];
    } else if ([@"selfEnableVideo" isEqualToString:call.method] && !(selfPartcipant.videoEnabled)) {
        [selfPartcipant toggleVideo];
    } else if ([@"selfPin" isEqualToString :call.method]) {
        [selfPartcipant selfPin];
    } else if ([@"unpin"  isEqualToString :call.method]) {
        [selfPartcipant selfUnpin];
    }
    //TODO: Screensharing implementation pending
    else {
        NSLog(@"😓 Method not implemented %@", call.method);
        result(FlutterMethodNotImplemented);
    }
}




@end

==> dyte_client-0.2.1.tar.gz: ios/Classes/DyteMeetingPlugin.m <==
//
//  DyteMeetingPlugin.m
//  dyte_client
//
//  Created by Rohit Bhatia on 7/12/21.
//

#import "DyteMeetingPlugin.h"
#import <Flutter/Flutter.h>
#import <UIKit/UIKit.h>
#import "FLNativeViewFactory.h"

@import DyteSdk;


static NSString *const CHANNEL_NAME = @"dyte_client";

@interface DyteMeetingPlugin ()
@property(nonatomic, retain) FlutterMethodChannel *channel;
@end

@implementation DyteMeetingPlugin

+ (void)registerWithRegistrar:(nonnull NSObject<FlutterPluginRegistrar> *)registrar {
    FlutterMethodChannel *channel =
         [FlutterMethodChannel methodChannelWithName:CHANNEL_NAME
                                     binaryMessenger:[registrar messenger]];
    FLNativeViewFactory* factory =
        [[FLNativeViewFactory alloc] initWithMessenger:registrar.messenger];
    DyteMeetingPlugin *instance = [[DyteMeetingPlugin alloc] init];
     [registrar addMethodCallDelegate:instance channel:channel];
     [registrar addApplicationDelegate:instance];
    [registrar registerViewFactory:factory withId:@"dyte-meeting-view"];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    DyteSelfParticipant *selfPartcipant = [DyteSelfParticipant sharedInstance];
    DyteParticipants *participantsInstance = [DyteParticipants sharedInstance];
   
    if ([@"getPlatformVersion"  isEqualToString:call.method]) {
        UIDevice* device = UIDevice.currentDevice;
        result(device.systemVersion);
    } else if ([@"getSelf" isEqualToString:call.method]) {
        result(selfPartcipant);
    } else if ([@"getMeetingParticipants" isEqualToString:call.method]) {
        result(participantsInstance.participants);
    } else if ([@"selfEnableAudio"isEqualToString:call.method] && !(selfPartcipant.audioEnabled)) {
        // In SDK, we currently have toggle audio so we only fire this event if audio is not enabled
        [selfPartcipant enableAudio];
    } else if ([@"selfDisableAudio" isEqualToString:call.method] && selfPartcipant.audioEnabled) {
        [selfPartcipant disableAudio];
    } else if ([@"selfDisableVideo" isEqualToString:call.method] && selfPartcipant.videoEnabled) {
        [selfPartcipant enableVideo];
    } else if ([@"selfEnableVideo" isEqualToString:call.method] && !(selfPartcipant.videoEnabled)) {
        [selfPartcipant disableVideo];
    } else if ([@"selfPin" isEqualToString :call.method]) {
        [selfPartcipant selfPin];
    } else if ([@"selfPin" isEqualToString :call.method]) {
        [selfPartcipant selfPin];
    }
    else if ([@"leaveRoom"  isEqualToString :call.method]) {
        [selfPartcipant leaveRoom];
    }else {
        NSLog(@"😓 Method not implemented %@", call.method);
        result(FlutterMethodNotImplemented);
    }
}




@end
